EXPORTS
	?ActivateRfForEmergencyCall@RSsmEmergencyCallRfAdaptation@@QAEXAAVTRequestStatus@@@Z @ 1 NONAME ; void RSsmEmergencyCallRfAdaptation::ActivateRfForEmergencyCall(class TRequestStatus &)
	?Cancel@RSsmEmergencyCallRfAdaptation@@QAEXXZ @ 2 NONAME ; void RSsmEmergencyCallRfAdaptation::Cancel(void)
	?Close@RSsmEmergencyCallRfAdaptation@@QAEXXZ @ 3 NONAME ; void RSsmEmergencyCallRfAdaptation::Close(void)
	?Connect@RSsmEmergencyCallRfAdaptation@@QAEHH@Z @ 4 NONAME ; int RSsmEmergencyCallRfAdaptation::Connect(int)
	?Connect@RSsmEmergencyCallRfAdaptation@@QAEHXZ @ 5 NONAME ; int RSsmEmergencyCallRfAdaptation::Connect(void)
	?DeactivateRfForEmergencyCall@RSsmEmergencyCallRfAdaptation@@QAEXAAVTRequestStatus@@@Z @ 6 NONAME ; void RSsmEmergencyCallRfAdaptation::DeactivateRfForEmergencyCall(class TRequestStatus &)
	?InitializeLibL@RSsmEmergencyCallRfAdaptation@@SAXXZ @ 7 NONAME ; void RSsmEmergencyCallRfAdaptation::InitializeLibL(void)
	?UnInitializeLib@RSsmEmergencyCallRfAdaptation@@SAXXZ @ 8 NONAME ; void RSsmEmergencyCallRfAdaptation::UnInitializeLib(void)

